Module replace

Module replace 

Structs

ReplaceStats

Enums

ReplaceResult

Functions

add_replacement
calculate_statistics
replace_all_in_file
Performs search and replace operations in a file
replace_in_file
NOTE: this should only be called with search results from the same file
replacement_if_match
Performs a search and replace operation on a string if the pattern matches