pub fn replace_in_file(results: &mut [SearchResult]) -> Result<()>Expand description
NOTE: this should only be called with search results from the same file
pub fn replace_in_file(results: &mut [SearchResult]) -> Result<()>NOTE: this should only be called with search results from the same file