Structs
Enums
Functions
- add_
replacement - calculate_
statistics - replace_
all_ in_ file - Performs search and replace operations in a file
- replace_
in_ file - NOTE: this should only be called with search results from the same file
- replacement_
if_ match - Performs a search and replace operation on a string if the pattern matches